#!/usr/bin/python
"""
Simple example of function optimization
  using Spearmint

Considers minimizing a simple degree-4 polynomial:
   (x-1)^2 * (x+1) * (x-0)
See: http://www.wolframalpha.com/share/clip?f=d41d8cd98f00b204e9800998ecf8427es6uupsgf8a 

Usage:
>>> python simplepoly.py
Call as a script (no args) from within simplepoly/ directory
 will fill in *any* pending input/output pairs in the file "results.dat"
 located in the current directory.   
"""

def calc_poly( x ):
    return (x-1)**2 * (x+1) * x

def write_experiment_results( xs, ys, keeplines ):
    resfile = open('results.dat','w')
    for line in keeplines:
        resfile.write( line )
    for i in range(len(xs)):
        resfile.write( "% 9.5f 0 % 9.5f\n" % ( ys[i], xs[i] ) )
    resfile.close()  

def get_pending_inputs():
    resfile = open('results.dat','r')
    xs = []
    keeplines = list()
    for line in resfile.readlines():
        values = line.split()
        assert len(values) == 3
        val = values[0]
        dur = values[1]
        x   = float( values[2] )        
        if (val == 'P'):
            xs.append( x )
        else:
            keeplines.append( line )
    resfile.close()
    return xs, keeplines
             
def main():
    xs, existingResults = get_pending_inputs()
    if len(xs) == 0:
        print 'No pending experiments'
        return
    print 'Evaluating suggested inputs %s' % (' '.join( [str(x) for x in xs] ) )
    ys = [ calc_poly(x) for x in xs]
    write_experiment_results( xs, ys, existingResults )

if __name__ == '__main__':
    main()
